(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28699,       1186]*)
(*NotebookOutlinePosition[     29539,       1213]*)
(*  CellTagsIndexPosition[     29495,       1209]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9,
  Background->RGBColor[1, 0.995987, 0.760006]],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Keyboard Shortcuts Styles", "Section"],

Cell[CellGroupData[{

Cell["Default", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Head1"],
  CellFrame->{{0, 0}, {2, 0}},
  CellMargins->{{40, 30}, {10, 30}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0, 0.380011, 0],
  TextAlignment->Center,
  CounterIncrements->"Head1",
  CounterAssignments->{{"Head2", 0}, {"Head3", 0}},
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.210025, 0, 0.450019]],

Cell[StyleData["Head1", "Printout"],
  CellFrameColor->GrayLevel[0],
  FontSize->14,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Head2"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{38, 30}, {2, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Head2",
  CounterAssignments->{{"Head3", 0}},
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.210025, 0, 0.450019]],

Cell[StyleData["Head2", "Printout"],
  CellMargins->{{40, 30}, {0, 10}},
  FontSize->12,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Head3"],
  CellMargins->{{40, 30}, {0, 10}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Head3",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0.210025, 0, 0.450019]],

Cell[StyleData["Head3", "Printout"],
  CellMargins->{{40, 30}, {0, 12}},
  FontSize->11,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{40, 10}, {6, 6}},
  TextJustification->1,
  LineSpacing->{1, 2},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{40, 10}, {0, 8}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{45, Inherited}, {7, 7}},
  CellHorizontalScrolling->True,
  TextAlignment->Center,
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"],
  CellMargins->{{60, 30}, {4, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  TextAlignment->Center,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{50, 10}, {4, 8}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["User Defined", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Custom1"]],

Cell[StyleData["Custom1", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Custom2"]],

Cell[StyleData["Custom2", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Custom3"]],

Cell[StyleData["Custom3", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Book Specific Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ChapterNumber"],
  CellFrame->{{0, 0}, {0, 5}},
  CellMargins->{{18, 100}, {20, 60}},
  CellGroupingRules->{"SectionGrouping", 0},
  PageBreakAbove->True,
  CellFrameColor->RGBColor[0.210025, 0, 0.450019],
  CounterIncrements->"SectionNumber",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {
      "NumberedEquation", 0}},
  FontFamily->"Times",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.380011, 0],
  Background->RGBColor[1, 0.995987, 0.760006]],

Cell[StyleData["ChapterNumber", "Printout"],
  CellMargins->{{40, 200}, {10, 50}},
  CellFrameColor->GrayLevel[0],
  FontSize->12,
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{18, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameMargins->{{22, Inherited}, {Inherited, Inherited}},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}, {"Head1", 0}},
  FontFamily->"Times",
  FontSize->44,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.210025, 0, 0.450019]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{40, 30}, {10, 30}},
  FontSize->32,
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{18, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Times",
  FontSize->24,
  FontSlant->"Italic"],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{40, 30}, {10, 10}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{40, 10}, {12, 8}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Theorem"],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Lemma"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Lemma"],

Cell[StyleData["Lemma", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Reference"],
  CellMargins->{{24, 10}, {6, 6}},
  TextJustification->1,
  LineSpacing->{1, 0},
  CounterIncrements->"Reference"],

Cell[StyleData["Reference", "Printout"],
  CellMargins->{{40, 10}, {0, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{55, 30}, {5, 3}},
  PageBreakAbove->False,
  TextAlignment->Center,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{60, 30}, {0, 8}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Figure"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  CounterIncrements->"Figure",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Figure", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableHead"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"TableHead"],

Cell[StyleData["TableHead", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True,
  StyleMenuListing->None],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{12, Inherited}, {7, 7}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item1"],
  CellMargins->{{48, 4}, {4, 4}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-23],

Cell[StyleData["Item1", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item1Continued"],
  CellMargins->{{71, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8}],

Cell[StyleData["Item1Continued", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item2"],
  CellMargins->{{71, 4}, {3, 3}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-21,
  StyleMenuListing->None],

Cell[StyleData["Item2", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item2Continued"],
  CellMargins->{{92, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None],

Cell[StyleData["Item2Continued", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item3"],
  CellMargins->{{94, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-23,
  StyleMenuListing->None],

Cell[StyleData["Item3", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item3Continued"],
  CellMargins->{{117, 4}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 15},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None],

Cell[StyleData["Item3Continued", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["HighlightBox"],
  CellFrame->True,
  CellMargins->{{18, 10}, {8, 8}},
  CellGroupingRules->{"NormalGrouping", 15},
  CellHorizontalScrolling->True,
  CellFrameColor->GrayLevel[0],
  StyleMenuListing->None,
  Background->RGBColor[0.8, 0.8, 1],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->1}],

Cell[StyleData["HighlightBox", "Printout"],
  CellMargins->{{18, 30}, {0, 8}},
  CellFrameColor->GrayLevel[0],
  Background->GrayLevel[0.900008]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "UserGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["UserGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ReferenceLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["ReferenceLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SamplesLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Samples", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["SamplesLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserDocsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "UserDocs", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["UserDocsLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Outline Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Outline1"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  ParagraphIndent->-38,
  CounterIncrements->"Outline1",
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral},
  StyleMenuListing->None,
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Outline1", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline2"],
  CellMargins->{{59, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  ParagraphIndent->-27,
  CounterIncrements->"Outline2",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)},
  StyleMenuListing->None,
  FontSize->15,
  FontWeight->"Bold"],

Cell[StyleData["Outline2", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline3"],
  CellMargins->{{108, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  ParagraphIndent->-21,
  CounterIncrements->"Outline3",
  CounterBoxOptions->{CounterFunction:>Identity},
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["Outline3", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline4"],
  CellMargins->{{158, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  ParagraphIndent->-18,
  CounterIncrements->"Outline4",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "a", "z"], #]&)},
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["Outline4", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Conformance Styles", "Section"],

Cell[CellGroupData[{

Cell["Backward Compatible Headings Styles", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{40, 10}, {0, 8}},
  CounterIncrements->"Author",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Author", "Printout"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Address"],
  CellMargins->{{40, 10}, {0, 8}},
  CounterIncrements->"Address",
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["Address", "Printout"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->None,
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Backward Compatible Text Styles", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText",
  StyleMenuListing->None],

Cell[StyleData["ItemizedText", "Printout"],
  ParagraphIndent->-18,
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{41, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text",
  StyleMenuListing->None],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedPicture"],
  CellMargins->{{41, Inherited}, {4, 4}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None],

Cell[StyleData["ItemizedPicture", "Printout"],
  CellMargins->{{38, 4}, {8, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text",
  StyleMenuListing->None],

Cell[StyleData["IndentedText", "Printout"],
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{46, 42}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Subsection"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[StyleData["InputOnly"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  FontSize->9,
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{505, 527},
WindowMargins->{{18, Automatic}, {Automatic, 1}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 62, "Subtitle"],
Cell[1771, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 42, 0, 50, "Section"],
Cell[2034, 63, 124, 3, 52, 31, 0, "StyleData", "All", "Working"],
Cell[2161, 68, 140, 4, 34, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2338, 77, 35, 0, 30, "Section"],
Cell[2376, 79, 101, 3, 30, "Text"],
Cell[2480, 84, 496, 13, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3013, 102, 44, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[3082, 106, 29, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[3136, 110, 398, 11, 87, 24, 0, "StyleData", "Head1", "All",
  CounterIncrements->"Head1",
  CounterAssignments->{{"Head2", 0}, {"Head3", 0}}],
Cell[3537, 123, 111, 3, 82, 36, 0, "StyleData", "Head1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3685, 131, 341, 10, 48, 24, 0, "StyleData", "Head2", "All",
  CounterIncrements->"Head2",
  CounterAssignments->{{"Head3", 0}}],
Cell[4029, 143, 115, 3, 48, 36, 0, "StyleData", "Head2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4181, 151, 270, 8, 36, 24, 0, "StyleData", "Head3", "All",
  CounterIncrements->"Head3"],
Cell[4454, 161, 115, 3, 39, 36, 0, "StyleData", "Head3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4606, 169, 134, 4, 42, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[4743, 175, 109, 3, 35, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4889, 183, 236, 6, 43, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[5128, 191, 96, 2, 39, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5261, 198, 366, 8, 40, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[5630, 208, 98, 2, 39, 47, 0, "StyleData", "NumberedEquation", 
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5777, 216, 34, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[5836, 220, 26, 0, 36, 26, 0, "StyleData", "Custom1", "All"],
Cell[5865, 222, 71, 1, 40, 38, 0, "StyleData", "Custom1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5973, 228, 26, 0, 36, 26, 0, "StyleData", "Custom2", "All"],
Cell[6002, 230, 71, 1, 40, 38, 0, "StyleData", "Custom2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6110, 236, 26, 0, 36, 26, 0, "StyleData", "Custom3", "All"],
Cell[6139, 238, 71, 1, 40, 38, 0, "StyleData", "Custom3", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6271, 246, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[6335, 250, 494, 13, 138, 32, 0, "StyleData", "ChapterNumber", "All",
  CounterIncrements->"SectionNumber",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {
      "NumberedEquation", 0}}],
Cell[6832, 265, 185, 5, 103, 44, 0, "StyleData", "ChapterNumber", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7054, 275, 494, 12, 108, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}, {"Head1", 0}}],
Cell[7551, 289, 144, 4, 88, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7732, 298, 334, 9, 68, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[8069, 309, 92, 2, 56, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8198, 316, 443, 13, 57, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[8644, 331, 94, 2, 50, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8775, 338, 116, 3, 43, 26, 0, "StyleData", "Theorem", "All",
  CounterIncrements->"Theorem"],
Cell[8894, 343, 71, 1, 44, 38, 0, "StyleData", "Theorem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9002, 349, 112, 3, 43, 24, 0, "StyleData", "Lemma", "All",
  CounterIncrements->"Lemma"],
Cell[9117, 354, 69, 1, 40, 36, 0, "StyleData", "Lemma", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9223, 360, 144, 4, 42, 28, 0, "StyleData", "Reference", "All",
  CounterIncrements->"Reference"],
Cell[9370, 366, 90, 2, 53, 40, 0, "StyleData", "Reference", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9497, 373, 153, 5, 38, 26, 0, "StyleData", "Caption", "All"],
Cell[9653, 380, 88, 2, 31, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9778, 387, 157, 5, 33, 25, 0, "StyleData", "Figure", "All",
  CounterIncrements->"Figure"],
Cell[9938, 394, 85, 2, 29, 37, 0, "StyleData", "Figure", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10060, 401, 120, 3, 43, 28, 0, "StyleData", "TableHead", "All",
  CounterIncrements->"TableHead"],
Cell[10183, 406, 73, 1, 40, 40, 0, "StyleData", "TableHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10293, 412, 101, 2, 36, 26, 0, "StyleData", "Picture", "All"],
Cell[10397, 416, 79, 1, 36, 38, 0, "StyleData", "Picture", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10525, 423, 43, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[10593, 427, 172, 5, 40, 32, 0, "StyleData", "InlineFormula", "All",
  StyleMenuListing->None],
Cell[10768, 434, 77, 1, 40, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10882, 440, 166, 4, 56, 26, 0, "StyleData", "Program", "All"],
Cell[11051, 446, 98, 2, 51, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11198, 454, 28, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[11251, 458, 162, 5, 41, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[11416, 465, 88, 2, 33, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11541, 472, 156, 4, 40, 24, 0, "StyleData", "Item1", "All"],
Cell[11700, 478, 70, 1, 36, 36, 0, "StyleData", "Item1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11807, 484, 141, 3, 38, 33, 0, "StyleData", "Item1Continued", "All"],
Cell[11951, 489, 79, 1, 36, 45, 0, "StyleData", "Item1Continued", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12067, 495, 182, 5, 39, 24, 0, "StyleData", "Item2", "All",
  StyleMenuListing->None],
Cell[12252, 502, 70, 1, 32, 36, 0, "StyleData", "Item2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12359, 508, 167, 4, 38, 33, 0, "StyleData", "Item2Continued", "All",
  StyleMenuListing->None],
Cell[12529, 514, 79, 1, 32, 45, 0, "StyleData", "Item2Continued", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12645, 520, 182, 5, 38, 24, 0, "StyleData", "Item3", "All",
  StyleMenuListing->None],
Cell[12830, 527, 70, 1, 32, 36, 0, "StyleData", "Item3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12937, 533, 168, 4, 38, 33, 0, "StyleData", "Item3Continued", "All",
  StyleMenuListing->None],
Cell[13108, 539, 79, 1, 32, 45, 0, "StyleData", "Item3Continued", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13236, 546, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[13300, 550, 352, 9, 64, 31, 0, "StyleData", "HighlightBox", "All",
  StyleMenuListing->None],
Cell[13655, 561, 145, 3, 52, 43, 0, "StyleData", "HighlightBox", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13849, 570, 36, 0, 30, "Section"],
Cell[13888, 572, 121, 3, 33, "Text"],
Cell[14012, 577, 92, 3, 40, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[14107, 582, 69, 2, 40, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[14179, 586, 70, 2, 40, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[14252, 590, 115, 4, 40, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[14370, 596, 116, 4, 40, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[14489, 602, 114, 4, 40, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[14606, 608, 116, 4, 40, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[14725, 614, 117, 4, 40, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[14845, 620, 118, 4, 41, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[14966, 626, 116, 4, 41, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[15085, 632, 118, 4, 41, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[15206, 638, 119, 4, 40, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[15328, 644, 120, 4, 40, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[15451, 650, 118, 4, 40, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[15572, 656, 120, 4, 40, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[15729, 665, 35, 0, 30, "Section"],
Cell[15767, 667, 184, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[15976, 675, 302, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16281, 685, 107, 2, 36, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[16403, 690, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[16532, 697, 328, 8, 36, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16863, 707, 116, 2, 36, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17016, 714, 318, 8, 36, 32, 0, "StyleData", "UserGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17337, 724, 111, 2, 36, 44, 0, "StyleData", "UserGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17485, 731, 325, 8, 36, 32, 0, "StyleData", "ReferenceLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17813, 741, 111, 2, 36, 44, 0, "StyleData", "ReferenceLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17961, 748, 314, 8, 36, 30, 0, "StyleData", "SamplesLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18278, 758, 109, 2, 36, 42, 0, "StyleData", "SamplesLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18424, 765, 316, 8, 36, 31, 0, "StyleData", "UserDocsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18743, 775, 110, 2, 36, 43, 0, "StyleData", "UserDocsLink", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18902, 783, 33, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[18960, 787, 290, 8, 51, 27, 0, "StyleData", "Outline1", "All",
  CounterIncrements->"Outline1",
  StyleMenuListing->None],
Cell[19253, 797, 39, 0, 51, 39, 0, "StyleData", "Outline1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19329, 802, 316, 9, 42, 27, 0, "StyleData", "Outline2", "All",
  CounterIncrements->"Outline2",
  StyleMenuListing->None],
Cell[19648, 813, 39, 0, 45, 39, 0, "StyleData", "Outline2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19724, 818, 258, 7, 39, 27, 0, "StyleData", "Outline3", "All",
  CounterIncrements->"Outline3",
  StyleMenuListing->None],
Cell[19985, 827, 39, 0, 42, 39, 0, "StyleData", "Outline3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20061, 832, 295, 8, 38, 27, 0, "StyleData", "Outline4", "All",
  CounterIncrements->"Outline4",
  StyleMenuListing->None],
Cell[20359, 842, 39, 0, 41, 39, 0, "StyleData", "Outline4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20447, 848, 49, 0, 30, "Section"],
Cell[20499, 850, 123, 4, 32, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[20625, 856, 122, 4, 30, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[20750, 862, 127, 4, 32, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[20914, 871, 37, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[20976, 875, 57, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[21058, 879, 139, 4, 40, 25, 0, "StyleData", "Author", "All",
  CounterIncrements->"Author",
  StyleMenuListing->None],
Cell[21200, 885, 53, 1, 40, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21290, 891, 142, 4, 36, 26, 0, "StyleData", "Address", "All",
  CounterIncrements->"Address",
  StyleMenuListing->None],
Cell[21435, 897, 54, 1, 38, 38, 0, "StyleData", "Address", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21526, 903, 362, 10, 48, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[21891, 915, 89, 2, 61, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22017, 922, 327, 9, 46, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[22347, 933, 91, 2, 59, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22475, 940, 271, 7, 44, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection",
  StyleMenuListing->None],
Cell[22749, 949, 94, 2, 48, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22892, 957, 53, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[22970, 961, 203, 6, 36, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"ItemizedText",
  StyleMenuListing->None],
Cell[23176, 969, 83, 2, 31, 43, 0, "StyleData", "ItemizedText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23296, 976, 175, 5, 36, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text",
  StyleMenuListing->None],
Cell[23474, 983, 97, 2, 31, 47, 0, "StyleData", "ItemizedTextNote", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23608, 990, 135, 3, 40, 34, 0, "StyleData", "ItemizedPicture", "All",
  StyleMenuListing->None],
Cell[23746, 995, 80, 1, 44, 46, 0, "StyleData", "ItemizedPicture", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23863, 1001, 171, 5, 36, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text",
  StyleMenuListing->None],
Cell[24037, 1008, 59, 1, 33, 43, 0, "StyleData", "IndentedText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24133, 1014, 241, 7, 36, 30, 0, "StyleData", "MathCaption", "All",
  StyleMenuListing->None],
Cell[24377, 1023, 121, 3, 41, 42, 0, "StyleData", "MathCaption", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24547, 1032, 45, 0, 31, "Subsection"],
Cell[24595, 1034, 364, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[24984, 1044, 460, 14, 44, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[25447, 1060, 85, 2, 36, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[25547, 1065, 309, 10, 40, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[25881, 1079, 480, 14, 44, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[26364, 1095, 86, 2, 36, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26487, 1102, 501, 14, 40, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[26991, 1118, 138, 3, 32, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27166, 1126, 465, 13, 40, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[27634, 1141, 109, 2, 32, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27780, 1148, 439, 12, 40, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[28222, 1162, 127, 3, 29, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28386, 1170, 128, 4, 37, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[28517, 1176, 130, 4, 32, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

