(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     46449,       1946]*)
(*NotebookOutlinePosition[     47101,       1969]*)
(*  CellTagsIndexPosition[     47057,       1965]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions for On-line Help", "Subtitle"],

Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Subsubsection"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  ShowAutoStyles->False,
  ScriptMinSize->9],

Cell[StyleData[All, "Brackets"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Subsubsection"],

Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {"Printed from the ", 
            StyleBox[ "Mathematica", FontSlant -> "Italic"], 
            " Help Browser"}], "PageHeader"]}, {Cell[ 
          TextData[ {"Printed from the ", 
            StyleBox[ "Mathematica", FontSlant -> "Italic"], 
            " Help Browser"}], "PageHeader"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageFooters->{{None, Cell[ 
          
          TextData[ {
            "\[Copyright]1997 Wolfram Research, Inc. All rights reserved."}], 
          "PageFooter"], None}, {None, Cell[ 
          
          TextData[ {
            "\[Copyright]1997 Wolfram Research, Inc. All rights reserved."}], 
          "PageFooter"], None}},
  PageHeaderLines->{True, True},
  PageFooterLines->{True, True},
  PrintingOptions->{"FacingPages"->True},
  CellLabelAutoDelete->False,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Headings", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["Chapter"],
  CellMargins->{{10, 4}, {4, 24}},
  FontFamily->"Helvetica",
  FontSize->24,
  FontWeight->"Bold"],

Cell[StyleData["Chapter", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->22]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{10, 4}, {12, 18}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, 4}, {0, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->18},
  CellFrameLabelMargins->6,
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{16, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{10, 4}, {0, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->18},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsubsectionColor"],
  CellMargins->{{10, 4}, {0, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->18},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0.297993, 0, 0.454994]],

Cell[StyleData["SubsubsectionColor", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsectionIcon"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{24, 4}, {0, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->8},
  CellGroupingRules->{"SectionGrouping", 50},
  CounterIncrements->"Section",
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["SubsectionIcon", "Printout"],
  CellDingbat->"\[FilledSquare]",
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{16, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsubsectionIcon"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{24, 4}, {0, 8}},
  CellElementSpacings->{"ClosedGroupTopMargin"->4},
  CellGroupingRules->{"SectionGrouping", 60},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubection", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["SubsubsectionIcon", "Printout"],
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Text", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ParagraphSpacing->{0, 8}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CompactText"],
  CellMargins->{{10, 4}, {0, 8}},
  ParagraphSpacing->{0, 0},
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["CompactText", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Compact12Text"],
  CellMargins->{{10, 4}, {0, 8}},
  ParagraphSpacing->{0, 0},
  StyleMenuListing->None],

Cell[StyleData["Compact12Text", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TextSans"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["TextSans", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 8}},
  ParagraphSpacing->{0, 8},
  ParagraphIndent->-15,
  StyleMenuListing->None],

Cell[StyleData["ItemizedText", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{35, 4}, {0, 4}},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None],

Cell[StyleData["IndentedText", "Printout"],
  CellMargins->{{12, 0}, {0, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{19, 62}, {0, 14}},
  PageBreakBelow->False,
  CellFrameLabelMargins->4,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.4]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{9, 0}, {0, 14}},
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{10, 4}, {0, 8}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"SmallText",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  TextJustification->1,
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Input/Output", "Subsubsection"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  ShowCellBracket->True,
  CellMargins->{{46, 4}, {3, 8}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelAutoDelete->False,
  CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  ShowSpecialCharacters->Automatic,
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  ShowCellBracket->True,
  CellMargins->{{47, 4}, {4, 2}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelAutoDelete->False,
  CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->StandardForm],

Cell[StyleData["Output", "Printout"],
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  ShowCellBracket->True,
  CellMargins->{{47, 4}, {4, 2}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Printout"],
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  ShowCellBracket->True,
  CellMargins->{{47, 4}, {4, 2}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  ShowCellBracket->True,
  CellMargins->{{47, 4}, {4, 2}},
  CellGroupingRules->"GraphicsGrouping",
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultFormatTypeForOutput,
  FormatType->InputForm,
  StyleMenuListing->None,
  FontWeight->"Plain"],

Cell[StyleData["Graphics", "Printout"],
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->7,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Name"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Name", "Printout"],
  FontSize->7,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlinks", "Subsubsection"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None",
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MainBookLinkMR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLinkMR", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Subsubsection"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["JT"],
  StyleMenuListing->None,
  FontFamily->"JFontText"],

Cell[StyleData["JS"],
  StyleMenuListing->None,
  FontFamily->"JFontSans"],

Cell[StyleData["JSB"],
  StyleMenuListing->None,
  FontFamily->"JFontSansBold"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["M4"],
  ShowCellBracket->True,
  StyleMenuListing->None,
  FontFamily->"Math4",
  CharacterEncoding->"Math4"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["C1"],
  StyleMenuListing->None,
  FontColor->RGBColor[0.4, 0, 1]],

Cell[StyleData["C1", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["C1MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontColor->RGBColor[0.4, 0, 1]],

Cell[StyleData["C1MR", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Emphasis Boxes and Pictures", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["Box"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->1}],

Cell[StyleData["Box", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DoubleBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->2,
  RowAlignments->Top}],

Cell[StyleData["DoubleBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["1ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->1}],

Cell[StyleData["1ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],

Cell[StyleData["2ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnEvenBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnWidths->0.46}],

Cell[StyleData["2ColumnEvenBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnSmallBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->1.5,
  ColumnWidths->0.35,
  ColumnAlignments->{Right, Left}}],

Cell[StyleData["2ColumnSmallBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnWidths->0.31}],

Cell[StyleData["3ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnSmallBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->1.5,
  ColumnWidths->0.24,
  ColumnAlignments->{Right, Center, Left}}],

Cell[StyleData["3ColumnSmallBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],

Cell[StyleData["4ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnWidths->0.194}],

Cell[StyleData["5ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["6ColumnBox"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],

Cell[StyleData["6ColumnBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedNoteBox"],
  CellFrame->0.5,
  CellMargins->{{37, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
  GridBoxOptions->{ColumnSpacings->1}],

Cell[StyleData["ItemizedNoteBox", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.4, 0.6},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox3Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.35, 0.2, 0.45},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox3Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox4Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.15, 0.35, 0.15, 0.35},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox4Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox5Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->0.2,
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox5Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox6Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox6Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleBox", "Printout"],
  CellMargins->{{2, 0}, {0, 0}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BottomBox"],
  CellFrame->{{0.5, 0.5}, {0.5, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["BottomBox", "Printout"],
  CellMargins->{{2, 4}, {0, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopSpanBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, 0}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleSpanBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{10, Inherited}, {0, 8}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedPicture"],
  CellMargins->{{35, 4}, {0, 4}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  StyleMenuListing->None],

Cell[StyleData["ItemizedPicture", "Printout"],
  CellMargins->{{27, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PictureGroup"],
  CellMargins->{{10, Inherited}, {0, 8}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  StyleMenuListing->None],

Cell[StyleData["PictureGroup", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Sound"],
  CellMargins->{{10, Inherited}, {0, 8}},
  StyleMenuListing->None],

Cell[StyleData["Sound", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{10, 4}, {0, 3}},
  PageBreakAbove->False,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{2, 0}, {0, 3}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tables", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->{0.34, 0.64},
  ColumnAlignments->{Left}}],

Cell[StyleData["2ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnEvenTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.49,
  ColumnAlignments->{Left}}],

Cell[StyleData["2ColumnEvenTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
  ColumnAlignments->{Left}}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True,
  SpanMaxSize->Infinity,
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InlineOutput"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["InlineOutput", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->9.5]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, Inherited}, {Inherited, 10}},
  CellHorizontalScrolling->True,
  ScriptLevel->0,
  SingleLetterItalics->True,
  SpanMaxSize->Infinity,
  StyleMenuListing->None,
  UnderoverscriptBoxOptions->{LimitsPositioning->True},
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["DisplayFormula", "Printout"],
  CellMargins->{{34, Inherited}, {Inherited, 10}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayMath"],
  CellMargins->{{42, 10}, {7, 7}},
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input"],

Cell[StyleData["DisplayMath", "Printout"],
  CellMargins->{{39, 0}, {6, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{42, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{34, 55}, {0, 10}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["EquationNumber"],
  LineSpacing->{1.83, 0}],

Cell[StyleData["EquationNumber", "Printout"],
  LineSpacing->{1.7, 0}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellMargins->{{16, Inherited}, {Inherited, 10}},
  CellHorizontalScrolling->True,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{8, Inherited}, {Inherited, 10}},
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unique Help Browser Styles", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["ObjectName"],
  CellMargins->{{10, 4}, {1, 10}},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["ObjectName", "Printout"],
  CellMargins->{{2, 0}, {1, 10}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Command"],
  CellMargins->{{10, 4}, {0, 14}},
  CounterIncrements->"Section",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Command", "Printout"],
  CellMargins->{{2, 0}, {0, 14}},
  PageBreakBelow->False,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CharacterName"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{10, 4}, {0, 4}},
  CellFrameMargins->4,
  StyleMenuListing->None],

Cell[StyleData["CharacterName", "Printout"],
  CellMargins->{{2, 0}, {0, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Usage"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{10, 4}, {0, 4}},
  CellFrameMargins->5,
  ParagraphSpacing->{0, 6},
  ParagraphIndent->-10,
  StyleMenuListing->None],

Cell[StyleData["Usage", "Printout"],
  CellMargins->{{2, 0}, {0, 4}},
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Notes"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ParagraphSpacing->{0, 6},
  ParagraphIndent->-10,
  StyleMenuListing->None,
  FontFamily->"Times"],

Cell[StyleData["Notes", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NotesList"],
  CellMargins->{{20, 4}, {2, 8}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True,
  StyleMenuListing->None,
  FontFamily->"Times"],

Cell[StyleData["NotesList", "Printout"],
  CellMargins->{{12, 0}, {2, 8}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExampleSection"],
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{11, 4}, {0, 10}},
  CellGroupingRules->{"SectionGrouping", 70},
  CellFrameMargins->12,
  StyleMenuListing->None,
  FontSize->13,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.4]],

Cell[StyleData["ExampleSection", "Printout"],
  CellMargins->{{3, 0}, {0, 10}},
  PageBreakBelow->False,
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExampleText"],
  ShowCellBracket->True,
  CellMargins->{{20, 40}, {0, 18}},
  ParagraphSpacing->{0, 6},
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 0.4]],

Cell[StyleData["ExampleText", "Printout"],
  CellMargins->{{2, 80}, {0, 8}},
  PageBreakBelow->False,
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ExampleSubsection"],
  ShowCellBracket->True,
  CellMargins->{{20, 4}, {0, 16}},
  CellGroupingRules->{"SectionGrouping", 80},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Bold"],

Cell[StyleData["ExampleSubsection", "Printout"],
  CellMargins->{{12, 0}, {0, 16}},
  PageBreakBelow->False,
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["LineHead"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{10, 4}, {8, 18}},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["LineHead", "Printout"],
  CellMargins->{{2, 0}, {8, 18}},
  PageBreakBelow->False]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FlushInput"],
  CellMargins->{{10, 4}, {1, 4}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelAutoDelete->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  ShowSpecialCharacters->Automatic,
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["FlushInput", "Printout"],
  CellMargins->{{2, 0}, {1, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FlushOutput"],
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelAutoDelete->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->StandardForm,
  StyleMenuListing->None],

Cell[StyleData["FlushOutput", "Printout"],
  CellMargins->{{2, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DialogItem"],
  CellDingbat->"\[EmptyDiamond]",
  CellMargins->{{20, 4}, {0, 12}},
  CellGroupingRules->{"SectionGrouping", 70},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Bold"],

Cell[StyleData["DialogItem", "Printout"],
  CellMargins->{{12, 0}, {0, 12}},
  PageBreakBelow->False,
  FontSize->8]
}, Closed]],

Cell[StyleData["GroupDivider"],
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  CellEditDuplicate->True,
  CellGroupingRules->{"TitleGrouping", 0},
  StyleMenuListing->None],

Cell[CellGroupData[{

Cell[StyleData["Highlight"],
  CellMargins->{{10, 4}, {0, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Highlight", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  LineSpacing->{1, 3}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserNotes"],
  CellFrame->{{2, 0}, {0, 0.25}},
  CellMargins->{{10, 4}, {0, 4}},
  ParagraphIndent->-7,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["UserNotes", "Printout"],
  CellMargins->{{2, 0}, {0, 4}},
  LineSpacing->{1, 3},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MoreInfo"],
  CellMargins->{{10, 4}, {0, 4}},
  ParagraphIndent->-7,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.700008, 0.4, 0.100008]],

Cell[StyleData["MoreInfo", "Printout"],
  CellMargins->{{2, 0}, {0, 4}},
  LineSpacing->{1, 3},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UserTips"],
  CellFrame->{{2, 0}, {0, 0.25}},
  CellMargins->{{10, 4}, {0, 4}},
  ParagraphIndent->-7,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0.500008, 0.700008]],

Cell[StyleData["UserTips", "Printout"],
  CellMargins->{{2, 0}, {0, 4}},
  LineSpacing->{1, 3},
  FontSize->8,
  Background->GrayLevel[0.700008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellFrame->{{4, 0}, {0, 0}},
  CellMargins->{{12, 62}, {0, 14}},
  CellFrameMargins->4,
  CellFrameColor->RGBColor[0, 0, 0.8],
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8}],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{2, 0}, {0, 14}},
  CellFrameMargins->3,
  CellFrameColor->GrayLevel[0.8],
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{36, 10}, {7, 7}},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0, 0.2, 1],
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  FontSlant->"Italic"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{32, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  CellMargins->{{10, 4}, {0, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{20, 4}, {3, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{20, 4}, {5, 20}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["IndexSection", "Printout"],
  CellMargins->{{12, 0}, {5, 20}},
  PageBreakBelow->False]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  CellMargins->{{21, 4}, {0, 8}},
  StyleMenuListing->None],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{13, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->9]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Horizontal Lines", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["Line1"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellMargins->{{10, 4}, {-16, 9}},
  StyleMenuListing->None,
  FontSize->2],

Cell[StyleData["Line1", "Printout"],
  CellMargins->{{2, 0}, {-16, 9}}]
}, Closed]],

Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["ProgramTop"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{10, 4}, {-18, 18}},
  LineSpacing->{1, -4},
  StyleMenuListing->None,
  FontSize->4],

Cell[StyleData["ProgramTop", "Printout"],
  CellMargins->{{2, 0}, {-18, 18}}]
}, Closed]],

Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["ProgramBottom"],
  CellFrame->{{0.5, 0.5}, {0.5, 0}},
  CellMargins->{{10, 4}, {-10, -2}},
  LineSpacing->{1, -4},
  StyleMenuListing->None,
  FontSize->4],

Cell[StyleData["ProgramBottom", "Printout"],
  CellMargins->{{2, 0}, {-10, -2}}]
}, Closed]],

Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["SessionLabel"],
  CellFrame->{{0.5, 0}, {0, 0.5}},
  CellMargins->{{10, 4}, {-4, 18}},
  LineSpacing->{1, -3},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SessionLabel", "Printout"],
  CellMargins->{{2, 0}, {-4, 18}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Page Headers and Footers", "Subsubsection"],

Cell[StyleData["PageHeader"],
  CellMargins->{{0, 0}, {2, 0}},
  StyleMenuListing->None,
  FontSize->8,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {2, 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["PageFooter"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->6]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"3.5 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowSize->{505, 471},
WindowMargins->{{7, Automatic}, {Automatic, 2}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 0, 64, "Subtitle"],
Cell[1796, 53, 139, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[1960, 60, 48, 0, 43, "Subsubsection"],
Cell[2011, 62, 128, 4, 40, 31, 0, "StyleData", "All", "Working"],
Cell[2142, 68, 78, 2, 40, 32, 0, "StyleData", "All", "Brackets"],
Cell[2223, 72, 140, 4, 37, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2400, 81, 41, 0, 29, "Subsubsection"],
Cell[2444, 83, 105, 3, 70, "Text"],
Cell[2552, 88, 1031, 25, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3620, 118, 33, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[3678, 122, 126, 4, 70, 26, 0, "StyleData", "Chapter", "All"],
Cell[3807, 128, 113, 3, 70, 38, 0, "StyleData", "Chapter", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3957, 136, 127, 4, 70, 26, 0, "StyleData", "Section", "All"],
Cell[4087, 142, 113, 3, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4237, 150, 244, 7, 70, 29, 0, "StyleData", "Subsection", "All"],
Cell[4484, 159, 117, 3, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4638, 167, 185, 5, 70, 32, 0, "StyleData", "Subsubsection", "All"],
Cell[4826, 174, 119, 3, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4982, 182, 262, 7, 70, 37, 0, "StyleData", "SubsubsectionColor", "All",
  StyleMenuListing->None],
Cell[5247, 191, 124, 3, 70, 49, 0, "StyleData", "SubsubsectionColor", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5408, 199, 295, 8, 70, 33, 0, "StyleData", "SubsectionIcon", "All",
  CounterIncrements->"Section"],
Cell[5706, 209, 188, 5, 70, 45, 0, "StyleData", "SubsectionIcon", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5931, 219, 345, 9, 70, 36, 0, "StyleData", "SubsubsectionIcon", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubection", 0}}],
Cell[6279, 230, 156, 4, 70, 48, 0, "StyleData", "SubsubsectionIcon", 
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6484, 240, 29, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[6538, 244, 118, 3, 70, 23, 0, "StyleData", "Text", "All"],
Cell[6659, 249, 68, 1, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6764, 255, 134, 4, 70, 30, 0, "StyleData", "CompactText", "All",
  StyleMenuListing->None],
Cell[6901, 261, 90, 2, 70, 42, 0, "StyleData", "CompactText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7028, 268, 120, 3, 70, 32, 0, "StyleData", "Compact12Text", "All",
  StyleMenuListing->None],
Cell[7151, 273, 93, 2, 70, 44, 0, "StyleData", "Compact12Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7281, 280, 191, 6, 70, 27, 0, "StyleData", "TextSans", "All",
  StyleMenuListing->None],
Cell[7475, 288, 87, 2, 70, 39, 0, "StyleData", "TextSans", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7599, 295, 143, 4, 70, 31, 0, "StyleData", "ItemizedText", "All",
  StyleMenuListing->None],
Cell[7745, 301, 77, 1, 70, 43, 0, "StyleData", "ItemizedText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7859, 307, 123, 3, 70, 35, 0, "StyleData", "ItemizedTextNote", "All",
  StyleMenuListing->None],
Cell[7985, 312, 81, 1, 70, 47, 0, "StyleData", "ItemizedTextNote", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8103, 318, 119, 3, 70, 31, 0, "StyleData", "IndentedText", "All",
  StyleMenuListing->None],
Cell[8225, 323, 77, 1, 70, 43, 0, "StyleData", "IndentedText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8339, 329, 243, 7, 70, 30, 0, "StyleData", "MathCaption", "All"],
Cell[8585, 338, 118, 3, 70, 42, 0, "StyleData", "MathCaption", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8740, 346, 164, 5, 70, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[8907, 353, 112, 3, 70, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9068, 362, 37, 0, 29, "Subsubsection"],
Cell[9108, 364, 252, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[9385, 373, 474, 14, 43, 24, 0, "StyleData", "Input", "All"],
Cell[9862, 389, 51, 1, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9950, 395, 457, 13, 40, 25, 0, "StyleData", "Output", "All"],
Cell[10410, 410, 52, 1, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10499, 416, 447, 13, 40, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[10949, 431, 80, 2, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11066, 438, 413, 12, 40, 24, 0, "StyleData", "Print", "All",
  StyleMenuListing->None],
Cell[11482, 452, 51, 1, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11570, 458, 350, 11, 40, 27, 0, "StyleData", "Graphics", "All",
  StyleMenuListing->None],
Cell[11923, 471, 54, 1, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12014, 477, 151, 5, 37, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[12168, 484, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12335, 493, 169, 6, 37, 23, 0, "StyleData", "Name", "All",
  StyleMenuListing->None],
Cell[12507, 501, 77, 2, 70, 35, 0, "StyleData", "Name", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12633, 509, 35, 0, 29, "Subsubsection"],
Cell[12671, 511, 340, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[13036, 521, 325, 9, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[13364, 532, 107, 2, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13508, 539, 279, 7, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None],
Cell[13790, 548, 110, 2, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13937, 555, 306, 8, 70, 33, 0, "StyleData", "MainBookLinkMR", "All",
  StyleMenuListing->None],
Cell[14246, 565, 112, 2, 70, 45, 0, "StyleData", "MainBookLinkMR", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14395, 572, 300, 8, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None],
Cell[14698, 582, 107, 2, 70, 40, 0, "StyleData", "AddOnLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14842, 589, 308, 8, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None],
Cell[15153, 599, 110, 2, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15300, 606, 291, 7, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  StyleMenuListing->None],
Cell[15594, 615, 116, 2, 70, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15747, 622, 295, 7, 70, 39, 0, "StyleData", "OtherInformationLink", 
"All",
  StyleMenuListing->None],
Cell[16045, 631, 118, 2, 70, 51, 0, "StyleData", "OtherInformationLink", 
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16212, 639, 42, 0, 29, "Subsubsection"],
Cell[16257, 641, 121, 3, 70, "Text"],
Cell[16381, 646, 74, 2, 70, 21, 0, "StyleData", "JT", "All",
  StyleMenuListing->None],
Cell[16458, 650, 74, 2, 70, 21, 0, "StyleData", "JS", "All",
  StyleMenuListing->None],
Cell[16535, 654, 79, 2, 70, 22, 0, "StyleData", "JSB", "All",
  StyleMenuListing->None],
Cell[16617, 658, 92, 3, 70, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[16712, 663, 69, 2, 70, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[16784, 667, 70, 2, 70, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[16857, 671, 115, 4, 70, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[16975, 677, 116, 4, 70, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[17094, 683, 114, 4, 70, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[17211, 689, 116, 4, 70, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[17330, 695, 117, 4, 70, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[17450, 701, 118, 4, 70, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[17571, 707, 116, 4, 70, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[17690, 713, 118, 4, 70, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[17811, 719, 119, 4, 70, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[17933, 725, 120, 4, 70, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[18056, 731, 118, 4, 70, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[18177, 737, 120, 4, 70, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],
Cell[18300, 743, 125, 4, 70, 21, 0, "StyleData", "M4", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[18450, 751, 138, 5, 70, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[18591, 758, 149, 5, 70, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[18777, 768, 81, 2, 70, 21, 0, "StyleData", "C1", "All",
  StyleMenuListing->None],
Cell[18861, 772, 60, 1, 70, 33, 0, "StyleData", "C1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18958, 778, 108, 3, 70, 23, 0, "StyleData", "C1MR", "All",
  StyleMenuListing->None],
Cell[19069, 783, 62, 1, 70, 35, 0, "StyleData", "C1MR", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19180, 790, 52, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[19257, 794, 246, 6, 56, 22, 0, "StyleData", "Box", "All",
  StyleMenuListing->None],
Cell[19506, 802, 102, 2, 70, 34, 0, "StyleData", "Box", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19645, 809, 274, 7, 52, 28, 0, "StyleData", "DoubleBox", "All",
  StyleMenuListing->None],
Cell[19922, 818, 108, 2, 70, 40, 0, "StyleData", "DoubleBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20067, 825, 270, 7, 52, 29, 0, "StyleData", "1ColumnBox", "All",
  StyleMenuListing->None],
Cell[20340, 834, 109, 2, 70, 41, 0, "StyleData", "1ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20486, 841, 279, 7, 52, 29, 0, "StyleData", "2ColumnBox", "All",
  StyleMenuListing->None],
Cell[20768, 850, 109, 2, 70, 41, 0, "StyleData", "2ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20914, 857, 275, 7, 52, 33, 0, "StyleData", "2ColumnEvenBox", "All",
  StyleMenuListing->None],
Cell[21192, 866, 113, 2, 70, 45, 0, "StyleData", "2ColumnEvenBox", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21342, 873, 334, 9, 52, 34, 0, "StyleData", "2ColumnSmallBox", "All",
  StyleMenuListing->None],
Cell[21679, 884, 114, 2, 70, 46, 0, "StyleData", "2ColumnSmallBox", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21830, 891, 271, 7, 52, 29, 0, "StyleData", "3ColumnBox", "All",
  StyleMenuListing->None],
Cell[22104, 900, 109, 2, 70, 41, 0, "StyleData", "3ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22250, 907, 342, 9, 52, 34, 0, "StyleData", "3ColumnSmallBox", "All",
  StyleMenuListing->None],
Cell[22595, 918, 114, 2, 70, 46, 0, "StyleData", "3ColumnSmallBox", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22746, 925, 291, 7, 52, 29, 0, "StyleData", "4ColumnBox", "All",
  StyleMenuListing->None],
Cell[23040, 934, 109, 2, 70, 41, 0, "StyleData", "4ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23186, 941, 272, 7, 52, 29, 0, "StyleData", "5ColumnBox", "All",
  StyleMenuListing->None],
Cell[23461, 950, 109, 2, 70, 41, 0, "StyleData", "5ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23607, 957, 303, 7, 52, 29, 0, "StyleData", "6ColumnBox", "All",
  StyleMenuListing->None],
Cell[23913, 966, 109, 2, 56, 41, 0, "StyleData", "6ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24059, 973, 293, 8, 53, 34, 0, "StyleData", "ItemizedNoteBox", "All",
  StyleMenuListing->None],
Cell[24355, 983, 97, 2, 54, 46, 0, "StyleData", "ItemizedNoteBox", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24489, 990, 352, 12, 53, 32, 0, "StyleData", "DefinitionBox", "All"],
Cell[24844, 1004, 128, 3, 52, 44, 0, "StyleData", "DefinitionBox", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25009, 1012, 363, 12, 53, 36, 0, "StyleData", "DefinitionBox3Col", "All"]
,
Cell[25375, 1026, 132, 3, 52, 48, 0, "StyleData", "DefinitionBox3Col", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25544, 1034, 370, 12, 53, 36, 0, "StyleData", "DefinitionBox4Col", 
"All"],
Cell[25917, 1048, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox4Col", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26086, 1056, 349, 12, 53, 36, 0, "StyleData", "DefinitionBox5Col", "All"]
,
Cell[26438, 1070, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox5Col", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26607, 1078, 382, 12, 53, 36, 0, "StyleData", "DefinitionBox6Col", "All"]
,
Cell[26992, 1092, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox6Col", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27161, 1100, 417, 14, 52, 25, 0, "StyleData", "TopBox", "All",
  StyleMenuListing->None],
Cell[27581, 1116, 105, 2, 70, 37, 0, "StyleData", "TopBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27723, 1123, 419, 14, 52, 28, 0, "StyleData", "MiddleBox", "All",
  StyleMenuListing->None],
Cell[28145, 1139, 108, 2, 70, 40, 0, "StyleData", "MiddleBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28290, 1146, 421, 14, 52, 28, 0, "StyleData", "BottomBox", "All",
  StyleMenuListing->None],
Cell[28714, 1162, 124, 3, 70, 40, 0, "StyleData", "BottomBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28875, 1170, 420, 14, 52, 29, 0, "StyleData", "TopSpanBox", "All",
  StyleMenuListing->None],
Cell[29298, 1186, 125, 3, 70, 41, 0, "StyleData", "TopSpanBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29460, 1194, 421, 14, 52, 32, 0, "StyleData", "MiddleSpanBox", "All",
  StyleMenuListing->None],
Cell[29884, 1210, 128, 3, 70, 44, 0, "StyleData", "MiddleSpanBox", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30049, 1218, 127, 3, 36, 26, 0, "StyleData", "Picture", "All",
  StyleMenuListing->None],
Cell[30179, 1223, 71, 1, 70, 38, 0, "StyleData", "Picture", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30287, 1229, 168, 4, 36, 34, 0, "StyleData", "ItemizedPicture", "All",
  StyleMenuListing->None],
Cell[30458, 1235, 80, 1, 70, 46, 0, "StyleData", "ItemizedPicture", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30575, 1241, 173, 4, 36, 31, 0, "StyleData", "PictureGroup", "All",
  StyleMenuListing->None],
Cell[30751, 1247, 76, 1, 70, 43, 0, "StyleData", "PictureGroup", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30864, 1253, 92, 2, 36, 24, 0, "StyleData", "Sound", "All",
  StyleMenuListing->None],
Cell[30959, 1257, 69, 1, 70, 36, 0, "StyleData", "Sound", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31065, 1263, 153, 5, 33, 26, 0, "StyleData", "Caption", "All",
  StyleMenuListing->None],
Cell[31221, 1270, 86, 2, 70, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31356, 1278, 31, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[31412, 1282, 217, 6, 70, 31, 0, "StyleData", "2ColumnTable", "All",
  StyleMenuListing->None],
Cell[31632, 1290, 76, 1, 70, 43, 0, "StyleData", "2ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31745, 1296, 213, 6, 70, 35, 0, "StyleData", "2ColumnEvenTable", "All",
  StyleMenuListing->None],
Cell[31961, 1304, 80, 1, 70, 47, 0, "StyleData", "2ColumnEvenTable", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32078, 1310, 223, 6, 70, 31, 0, "StyleData", "3ColumnTable", "All",
  StyleMenuListing->None],
Cell[32304, 1318, 76, 1, 70, 43, 0, "StyleData", "3ColumnTable", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32429, 1325, 49, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[32503, 1329, 242, 7, 70, 32, 0, "StyleData", "InlineFormula", "All",
  StyleMenuListing->None],
Cell[32748, 1338, 77, 1, 70, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32862, 1344, 149, 4, 70, 31, 0, "StyleData", "InlineOutput", "All",
  StyleMenuListing->None],
Cell[33014, 1350, 93, 2, 70, 43, 0, "StyleData", "InlineOutput", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33144, 1357, 316, 8, 70, 33, 0, "StyleData", "DisplayFormula", "All",
  StyleMenuListing->None],
Cell[33463, 1367, 96, 1, 70, 45, 0, "StyleData", "DisplayFormula", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33596, 1373, 389, 12, 70, 30, 0, "StyleData", "DisplayMath", "All",
  CounterIncrements->"Input"],
Cell[33988, 1387, 91, 2, 70, 42, 0, "StyleData", "DisplayMath", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34116, 1394, 318, 7, 70, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[34437, 1403, 99, 2, 70, 47, 0, "StyleData", "NumberedEquation", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34573, 1410, 59, 1, 70, 33, 0, "StyleData", "EquationNumber", "All"],
Cell[34635, 1413, 70, 1, 70, 45, 0, "StyleData", "EquationNumber", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34742, 1419, 161, 4, 70, 26, 0, "StyleData", "Program", "All",
  StyleMenuListing->None],
Cell[34906, 1425, 105, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[35060, 1433, 51, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[35136, 1437, 153, 5, 70, 29, 0, "StyleData", "ObjectName", "All",
  StyleMenuListing->None],
Cell[35292, 1444, 91, 2, 70, 41, 0, "StyleData", "ObjectName", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35420, 1451, 184, 6, 70, 26, 0, "StyleData", "Command", "All",
  CounterIncrements->"Section",
  StyleMenuListing->None],
Cell[35607, 1459, 113, 3, 70, 38, 0, "StyleData", "Command", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35757, 1467, 150, 4, 70, 32, 0, "StyleData", "CharacterName", "All",
  StyleMenuListing->None],
Cell[35910, 1473, 77, 1, 70, 44, 0, "StyleData", "CharacterName", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36024, 1479, 194, 6, 70, 24, 0, "StyleData", "Usage", "All",
  StyleMenuListing->None],
Cell[36221, 1487, 92, 2, 70, 36, 0, "StyleData", "Usage", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36350, 1494, 192, 6, 70, 24, 0, "StyleData", "Notes", "All",
  StyleMenuListing->None],
Cell[36545, 1502, 84, 2, 70, 36, 0, "StyleData", "Notes", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36666, 1509, 191, 6, 70, 28, 0, "StyleData", "NotesList", "All",
  StyleMenuListing->None],
Cell[36860, 1517, 89, 2, 70, 40, 0, "StyleData", "NotesList", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[36986, 1524, 324, 10, 70, 33, 0, "StyleData", "ExampleSection", "All",
  StyleMenuListing->None],
Cell[37313, 1536, 146, 4, 70, 45, 0, "StyleData", "ExampleSection", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37496, 1545, 179, 5, 70, 30, 0, "StyleData", "ExampleText", "All",
  StyleMenuListing->None],
Cell[37678, 1552, 143, 4, 70, 42, 0, "StyleData", "ExampleText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37858, 1561, 233, 7, 70, 36, 0, "StyleData", "ExampleSubsection", "All",
  StyleMenuListing->None],
Cell[38094, 1570, 123, 3, 70, 48, 0, "StyleData", "ExampleSubsection", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38254, 1578, 266, 8, 70, 27, 0, "StyleData", "LineHead", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubection", 0}},
  StyleMenuListing->None],
Cell[38523, 1588, 98, 2, 70, 39, 0, "StyleData", "LineHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38658, 1595, 513, 15, 70, 29, 0, "StyleData", "FlushInput", "All",
  StyleMenuListing->None],
Cell[39174, 1612, 74, 1, 70, 41, 0, "StyleData", "FlushInput", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39285, 1618, 487, 13, 70, 30, 0, "StyleData", "FlushOutput", "All",
  StyleMenuListing->None],
Cell[39775, 1633, 99, 1, 70, 42, 0, "StyleData", "FlushOutput", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39911, 1639, 235, 7, 70, 29, 0, "StyleData", "DialogItem", "All",
  StyleMenuListing->None],
Cell[40149, 1648, 116, 3, 70, 41, 0, "StyleData", "DialogItem", "Printout"]
}, Closed]],
Cell[40280, 1654, 185, 4, 70, 31, 0, "StyleData", "GroupDivider", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[40490, 1662, 167, 5, 70, 28, 0, "StyleData", "Highlight", "All",
  StyleMenuListing->None],
Cell[40660, 1669, 97, 2, 70, 40, 0, "StyleData", "Highlight", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40794, 1676, 188, 6, 70, 28, 0, "StyleData", "UserNotes", "All",
  StyleMenuListing->None],
Cell[40985, 1684, 111, 3, 70, 40, 0, "StyleData", "UserNotes", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41133, 1692, 229, 7, 70, 27, 0, "StyleData", "MoreInfo", "All",
  StyleMenuListing->None],
Cell[41365, 1701, 110, 3, 70, 39, 0, "StyleData", "MoreInfo", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41512, 1709, 263, 8, 70, 27, 0, "StyleData", "UserTips", "All",
  StyleMenuListing->None],
Cell[41778, 1719, 145, 4, 70, 39, 0, "StyleData", "UserTips", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41960, 1728, 206, 6, 70, 26, 0, "StyleData", "Theorem", "All"],
Cell[42169, 1736, 171, 5, 70, 38, 0, "StyleData", "Theorem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42377, 1746, 256, 8, 70, 29, 0, "StyleData", "Commentary", "All"],
Cell[42636, 1756, 125, 3, 70, 41, 0, "StyleData", "Commentary", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42810, 1765, 43, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[42878, 1769, 158, 5, 70, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[43039, 1776, 119, 3, 70, 44, 0, "StyleData", "ContentsTitle", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[43195, 1784, 194, 6, 70, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[43392, 1792, 106, 2, 70, 46, 0, "StyleData", "ContentsSection", 
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[43535, 1799, 191, 6, 70, 31, 0, "StyleData", "IndexSection", "All",
  StyleMenuListing->None],
Cell[43729, 1807, 103, 2, 70, 43, 0, "StyleData", "IndexSection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[43869, 1814, 87, 2, 70, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[43959, 1818, 73, 1, 70, 39, 0, "StyleData", "Contents", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[44069, 1824, 108, 3, 70, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[44180, 1829, 85, 2, 70, 36, 0, "StyleData", "Index", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[44302, 1836, 116, 3, 70, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[44421, 1841, 93, 2, 70, 44, 0, "StyleData", "IndexSubentry", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44563, 1849, 41, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[44629, 1853, 134, 4, 70, 24, 0, "StyleData", "Line1", "All",
  StyleMenuListing->None],
Cell[44766, 1859, 71, 1, 70, 36, 0, "StyleData", "Line1", "Printout"]
}, Closed]],
Cell[44852, 1863, 65, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[44942, 1870, 168, 5, 70, 29, 0, "StyleData", "ProgramTop", "All",
  StyleMenuListing->None],
Cell[45113, 1877, 77, 1, 70, 41, 0, "StyleData", "ProgramTop", "Printout"]
}, Closed]],
Cell[45205, 1881, 61, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[45291, 1889, 171, 5, 70, 32, 0, "StyleData", "ProgramBottom", "All",
  StyleMenuListing->None],
Cell[45465, 1896, 80, 1, 70, 44, 0, "StyleData", "ProgramBottom", "Printout"]
}, Closed]],
Cell[45560, 1900, 64, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[45649, 1908, 194, 6, 70, 31, 0, "StyleData", "SessionLabel", "All",
  StyleMenuListing->None],
Cell[45846, 1916, 93, 2, 70, 43, 0, "StyleData", "SessionLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[45988, 1924, 49, 0, 29, "Subsubsection"],
Cell[46040, 1926, 126, 4, 70, 29, 0, "StyleData", "PageHeader", "All",
  StyleMenuListing->None],
Cell[46169, 1932, 152, 5, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[46324, 1939, 97, 3, 70, 29, 0, "StyleData", "PageFooter", "All",
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

